diff --git a/utils/api_demos/mainHomology.cpp b/utils/api_demos/mainHomology.cpp
index 39b3e8b9cce55af7806867b48441cb40a583f832..f1e55608196b30eaf94b94482bccd4983ce9db7c 100644
--- a/utils/api_demos/mainHomology.cpp
+++ b/utils/api_demos/mainHomology.cpp
@@ -1,10 +1,10 @@
 // Gmsh - Copyright (C) 1997-2012 C. Geuzaine, J.-F. Remacle
-// 
+//
 // See the LICENSE.txt file for license information. Please report all
 // bugs and problems to <gmsh@geuz.org>.
-// 
+//
 // Contributed by Matti Pellikka <matti.pellikka@tut.fi>.
-// 
+//
 
 #include <stdio.h>
 #include <sstream>
@@ -18,17 +18,17 @@ int main(int argc, char **argv)
 {
   GmshInitialize(argc, argv);
   GModel *m = new GModel();
-  
+
   m->readGEO("model.geo");
   m->mesh(3);
   // OR
   // m->readMSH("model.msh");
-  
+
   // List of physical regions as domain for homology computation
   // (relative to subdomain).
   std::vector<int> domain;
   std::vector<int> subdomain;
-  
+
   // initialize
   Homology* homology = new Homology(m, domain, subdomain);
 
@@ -38,20 +38,20 @@ int main(int argc, char **argv)
   // construct cell complex of the meshed domain
   CellComplex cc = homology->createCellComplex();
 
-  // find homology generator chains
-  homology->findGenerators(cc);
+  // find homology basis elements
+  homology->findHomologyBasis(cc);
 
   // restore cell complex for a new run
-  cc->restoreComplex(); 
+  cc->restoreComplex();
 
-  // find thick cuts
-  homology->findDualGenerators(cc);
+  // find cohomology basis elements
+  homology->findCohomologyBasis(cc);
 
   delete cc;
   delete homology;
   delete m;
   GmshFinalize();
-  
+
 }